# scikit-event-correlation

Event Correlation and Forecasting over High Dimensional Streaming Sensor Data algorithms

## Theory
Correlating events in complex and dynamic IoT environments is a challenging task not only because of the amount of available data that needs to be processed but also due to the call for time efficient data processing. We propose the adoption of a univariate change detection algorithm for real-time event detection and we implement a stepwise event correlation scheme based on a first-order Markov model.


## Requirements
* Python 3.6 to 3.10 supported.
* scikit-learn 1.0.0 to 1.02 supported.


## Installation
1. Install with pip:
```
python -m pip install scikit-event-correlation
```


## Example Project
See the example project in the [example/](https://github.com/Intellia-SME/scikit-event-correlation/tree/main/example) directory of the GitHub repository.

